@@ -1,30 +1,40 @@
 
 # Check that reformat_GSOD functions properly ----------------------------------
 context("reformat_GSOD")
-file.remove(file.path(tempdir(), list.files(tempdir(), pattern = ".op.gz$")))
 test_that("reformat_GSOD file_list parameter reformats data properly", {
   skip_on_cran()
-
   do.call(file.remove, list(list.files(
     tempdir(),
     pattern = ".gz$",
     full.names = TRUE
   )))
 
+  # set up options for curl
+  ftp_handle <-
+    curl::new_handle(
+      ftp_use_epsv = FALSE,
+      crlf = TRUE,
+      ssl_verifypeer = FALSE,
+      ftp_response_timeout = 30,
+      ftp_skip_pasv_ip = TRUE
+    )
+
   ftp_base <- "ftp://ftp.ncdc.noaa.gov/pub/data/gsod/1960/"
   test_files <-
     c("066000-99999-1960.op.gz", "066200-99999-1960.op.gz")
-  dsn <- tempdir()
-  destinations <- file.path(dsn, test_files)
+  destinations <- file.path(tempdir(), test_files)
 
   Map(
     function(u, d)
-      download.file(u, d, mode = "wb"),
+      curl::curl_download(u, d,
+                          handle = ftp_handle,
+                          mode = "wb",
+                          quiet = TRUE),
     paste0(ftp_base, test_files),
     destinations
   )
 
-  file_list <- list.files(path = dsn,
+  file_list <- list.files(path = tempdir(),
                           pattern = "^.*\\.op.gz$",
                           full.names = TRUE)
   expect_equal(length(file_list), 2)
@@ -39,7 +49,7 @@ test_that("reformat_GSOD file_list parameter reformats data properly", {
   expect_is(x, "data.frame")
 
   # check that provided a dsn only, the function works properly
-  x <- reformat_GSOD(dsn = dsn)
+  x <- reformat_GSOD(dsn = tempdir())
   expect_equal(nrow(x), 722)
   expect_length(x, 48)
   expect_is(x, "data.frame")
